@@ -7,7 +7,10 @@
 #'   At the moment the following formats are supported using file readers 
 #'   already included with the nat package: \itemize{
 #'   
-#'   \item \bold{swc} See \code{\link{read.neuron.swc}}
+#'   \item \bold{swc} See \code{\link{read.neuron.swc}}. SWC files can also 
+#'   return an \code{\link{ngraph}} object containing the neuron structure in a
+#'   (permissive) general graph format that also contains the 3D positions for
+#'   each vertex.
 #'   
 #'   \item \bold{neuroml} See \code{\link{read.neuron.neuroml}}
 #'   
@@ -25,11 +28,13 @@
 #'   
 #'   }
 #' @export
-#' @param f Path to file. This can be a URL, in which case the file is
+#' @param f Path to file. This can be a URL, in which case the file is 
 #'   downloaded to a temporary location before reading.
 #' @param format The file format of the neuron. When \code{format=NULL}, the 
 #'   default, \code{read.neuron} will infer the file format from the extension 
 #'   or file header (aka magic) using the \code{fileformats} registry.
+#' @param class The class of the returned object - presently either 
+#'   \code{"neuron"} or \code{"ngraph"}
 #' @param ... additional arguments passed to format-specific readers
 #' @seealso \code{\link{read.neurons}, \link{fileformats}}
 #' @references Schmitt, S. and Evers, J. F. and Duch, C. and Scholz, M. and 
@@ -37,7 +42,6 @@
 #'   reconstruction of neurons from confocal image stacks. Neuroimage 4, 
 #'   1283--98. 
 #'   \href{http://dx.doi.org/10.1016/j.neuroimage.2004.06.047}{doi:10.1016/j.neuroimage.2004.06.047}
-#'     
 #' @examples
 #' \dontrun{
 #' # note that we override the default NeuronName field
@@ -49,7 +53,7 @@
 #' # show the currently registered file formats that we can read
 #' fileformats(class='neuron', read=TRUE)
 #' }
-read.neuron<-function(f, format=NULL, ...){
+read.neuron<-function(f, format=NULL, class=c("neuron", "ngraph"), ...){
   if(grepl("^http[s]{0,1}://", f)) {
     url=f
     # download remote url to local file in tempdir
@@ -68,12 +72,15 @@ read.neuron<-function(f, format=NULL, ...){
     if(length(objname)>1) stop("More than 1 object in file:",f)
     n=get(objname,envir=environment())
   } else {
-    ffs=getformatreader(f, class = 'neuron')
+    class=match.arg(class, choices = c("neuron", "ngraph"))
+    ffs=getformatreader(f, class = class)
     if(is.null(ffs)) {
       # as a special test, check to see if this looks like an swc file
       # we don't do this by default since is.swc is a little slow
-      if(is.swc(f)) n=read.neuron.swc(f, ...)
-      else stop("Unable to identify file type of:", f)
+      if(is.swc(f)) {
+        if(class=='neuron') n=read.neuron.swc(f, ...)
+        else n=read.ngraph.swc(f, ...)
+      } else stop("Unable to identify file type of:", f)
     } else {
       n=match.fun(ffs$read)(f, ...)
     }
@@ -83,7 +90,7 @@ read.neuron<-function(f, format=NULL, ...){
   }
   # make sure that neuron actually inherits from neuron
   # we can rely on dotprops/neuronlist objects to have the correct class
-  if(is.dotprops(n) || is.neuronlist(n)) n else as.neuron(n)
+  if(is.dotprops(n) || inherits(n, 'ngraph') || is.neuronlist(n)) n else as.neuron(n)
 }
 
 #' Read one or more neurons from file to a neuronlist in memory
@@ -315,15 +322,19 @@ fileformats<-function(format=NULL,ext=NULL,read=NULL,write=NULL,class=NULL,
   }
   rval=match.arg(rval)
   if(rval=='names'){
-    currentformats
-  } else if(rval=='info'){
-    t(sapply(currentformats,function(x) {
-      fx=get(x, envir=.fileformats)
-      c(fx[c('ext','class')],read=!is.null(fx$read),write=!is.null(fx$write),
-        magic=!is.null(fx$magic))
-    }))
+    return(currentformats)
+  }
+  fi=mget(currentformats, envir=.fileformats)
+  if(rval=='info'){
+    l=lapply(currentformats, function(f) {
+      fx=fi[[f]]
+      data.frame(format=f, class=fx$class, ext=fx$ext, 
+                 read=!is.null(fx$read), write=!is.null(fx$write),
+                 magic=!is.null(fx$magic))
+    })
+    do.call(rbind, l)
   } else if(rval=='all') {
-    mget(currentformats, envir=.fileformats)
+    fi
   }
 }
 
@@ -467,25 +478,55 @@ getformatwriter<-function(format=NULL, file=NULL, ext=NULL, class=NULL){
 }
 
 #' Read a neuron in swc file format
-#' 
-#' This function should normally only be called from read.neuron and is not 
-#' designed for use by end users.
+#' @description \code{read.neuron.swc} reads an SWC file on disk into a fully 
+#'   parsed \code{\link{neuron}} representation.
+#' @details These functions will accept SWC neurons with multiple trees and 
+#'   arbitrary point index order. However only \code{read.ngraph.swc} will
+#'   accept SWC files with cycles.
+#'   
+#'   These functions would normally be called from \code{read.neuron(s)} rather 
+#'   than used directly.
 #' @section SWC Format: According to 
-#'   \url{http://www.soton.ac.uk/~dales/morpho/morpho_doc} SWC file format has a
+#'   \url{http://research.mssm.edu/cnic/swc.html} SWC file format has a
 #'   radius not a diameter specification
 #' @param f path to file
-#' @param ... Additional arguments passed to \code{as.neuron()} and then on to 
-#'   \code{neuron()}
+#' @param ... Additional arguments. \code{read.neuron.swc} passes theseto 
+#'   \code{\link{as.neuron}} and then on to \code{\link{neuron}}. 
+#'   \code{read.neuron.swc} passes them to \code{\link{ngraph}}.
 #' @seealso \code{\link{is.swc}}
 read.neuron.swc<-function(f, ...){
+  d=read.swc(f)
+  # multiply by 2 to get diam which is what I work with internally
+  d$W=d$W*2
+  as.neuron(d, InputFileName=f, ...)
+}
+
+# internal function that just reads a table of SWC format data
+read.swc<-function(f){
   ColumnNames<-c("PointNo","Label","X","Y","Z","W","Parent")
   d=read.table(f, header = FALSE, sep = "", quote = "\"'", dec = ".",
                col.names=ColumnNames, check.names = TRUE, fill = FALSE,
                strip.white = TRUE, blank.lines.skip = TRUE, comment.char = "#",
                colClasses=c("integer",'integer','numeric','numeric','numeric','numeric','integer'))
+  badpids=d$Parent < -1
+  if(any(badpids)) {
+    warning("Invalid negative point index in file: ",f, ". Converting to -1")
+    d$Parent[badpids]=-1
+  }
+  d
+}
+
+#' @rdname read.neuron.swc
+#' @inheritParams ngraph
+#' @export
+#' @description \code{read.ngraph.swc} reads an SWC file on disk into the more 
+#'   generic (and forgiving) \code{\link{ngraph}} representation which provides
+#'   a bridge to the \code{\link[igraph]{igraph}} library.
+read.ngraph.swc<-function(f, weights=FALSE, directed=TRUE, ...){
+  d=read.swc(f)
   # multiply by 2 to get diam which is what I work with internally
   d$W=d$W*2
-  as.neuron(d, InputFileName=f, ...)
+  as.ngraph(d, weights=weights, directed=directed, ...)
 }
 
 #' Test if a file is an SWC format neuron
